.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

*********************************
Bluesky Event Model Documentation
*********************************

This repository contains the formal schemas for bluesky's streaming data model
and some Python tooling for composing, validating, and transforming documents
in the model.

.. toctree::
   :maxdepth: 2

   installation
   data-model
   external
   event-descriptors
   api
   release-history
